<?php

namespace SGalinski\SgJobs\Domain\Repository;

/**
 *
 * Copyright notice
 *
 * (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 * All rights reserved
 *
 * This script is part of the TYPO3 project. The TYPO3 project is
 * free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * The GNU General Public License can be found at
 * http://www.gnu.org/copyleft/gpl.html.
 *
 * This script is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * This copyright notice MUST APPEAR in all copies of the script!
 */

use TYPO3\CMS\Extbase\Persistence\Generic\Typo3QuerySettings;
use TYPO3\CMS\Extbase\Persistence\QueryInterface;
use TYPO3\CMS\Extbase\Persistence\QueryResultInterface;
use TYPO3\CMS\Extbase\Persistence\Repository;

/**
 * Repository class to get Countries
 *
 * @package SGalinski\SgJobs\Domain\Repository
 * @author Kevin Ditscheid <kevin.ditscheid@sgalinski.de>
 */
class CountryRepository extends Repository {

	/**
	 * Initialize the CountryRepository and set the storage page settings
	 */
	public function initializeObject() {
		$defaultQuerySettings = $this->objectManager->get(Typo3QuerySettings::class);
		$defaultQuerySettings->setRespectStoragePage(FALSE);
		$this->defaultQuerySettings = $defaultQuerySettings;
	}

	/**
	 * Find all countries ordered by the given language
	 *
	 * @param string $language
	 * @return QueryResultInterface
	 */
	public function findAllOrderedByLanguage(string $language): QueryResultInterface {
		$query = $this->createQuery();
		$query->setOrderings(
			[
				'cnShortEn' => QueryInterface::ORDER_ASCENDING
			]
		);
		if ($language === 'de') {
			$query->setOrderings(
				[
					'cnShortDe' => QueryInterface::ORDER_ASCENDING
				]
			);
		}
		if ($language === 'it') {
			$query->setOrderings(
				[
					'cnShortIt' => QueryInterface::ORDER_ASCENDING
				]
			);
		}
		if ($language === 'fr') {
			$query->setOrderings(
				[
					'cnShortFr' => QueryInterface::ORDER_ASCENDING
				]
			);
		}
		if ($language === 'es') {
			$query->setOrderings(
				[
					'cnShortEs' => QueryInterface::ORDER_ASCENDING
				]
			);
		}
		return $query->execute();
	}
}
